import { ReactElement } from "react";
import { CodeHighlighter } from "./code-highlighter";
import { Dialog, DialogContent, DialogDescription, DialogHeader, DialogTitle, DialogTrigger } from "./ui/dialog";

type CodeDialogProps = {
  /**
   * The title of the dialog.
   */
  title: string;

  /**
   * The description of the dialog.
   */
  description: string;

  /**
   * The code to show in the dialog.
   */
  code: string;

  /**
   * The children for this element.
   */
  children: React.ReactNode;
};

export function CodeDialog({ title, description, code, children }: CodeDialogProps): ReactElement {
  return (
    <Dialog>
      <DialogTrigger asChild>{children}</DialogTrigger>
      <DialogContent className="max-h-screen md:max-h-[700px] text-sm">
        <DialogHeader>
          <DialogTitle>{title}</DialogTitle>
          <DialogDescription>{description}</DialogDescription>
        </DialogHeader>
        <CodeHighlighter code={code} />
      </DialogContent>
    </Dialog>
  );
}
