import { CodeHighlighter } from "@/app/components/code-highlighter";
import { Separator } from "@/app/components/ui/separator";
import Link from "next/link";
import { ReactElement } from "react";

/**
 * Create a heading component.
 *
 * @param level The level of the heading.
 * @param props The props to pass to the heading.
 */
export function formatHeading(level: number, props: any): ReactElement {
  const Tag = `h${level}`;
  const paddingBottom = level > 1 ? "pt-6" : "";
  const textSize = 4 - level;

  return (
    <div className={`pb-4 ${paddingBottom}`}>
      <Tag className={`text-${textSize}xl font-semibold pb-2`} {...props} />
      <Separator />
    </div>
  );
}

/**
 * Format a code block.
 *
 * @param props The props to pass to the code block.
 */
export function formatCode(props: any): ReactElement {
  if (!props.className) {
    return <code className="text-xs bg-secondary p-1 rounded-md leading-none" {...props} />;
  }

  return (
    <div className="pt-4">
      <CodeHighlighter
        language={props.className ? props.className.replace("language-") : undefined}
        code={props.children}
      />
    </div>
  );
}

/**
 * Format a list.
 *
 * @param props The props to pass to the list.
 */
export function formatList(props: any): ReactElement {
  return <ul className="list-disc pl-4 ml-2 pt-2">{props.children}</ul>;
}

/**
 * Format a link.
 *
 * @param props The props to pass to the link.
 */
export function formatLink(props: any): ReactElement {
  return (
    <Link href={props.href} className="text-primary hover:opacity-85 transition-all transform-gpu">
      {props.children}
    </Link>
  );
}
